# Argument Names

A Python library that provides a decorator to automatically retrieve and print the argument names of a function when it's called. This can be particularly useful for debugging or logging purposes.